<?php
/*
Plugin Name: Related Posts Internal Link
Description: Adds internal links to related posts if no internal links are present in the post.
Version: 1.0
Author: Rifan Muazin
*/

// Hook to run the function when a post is viewed
add_action('wp', 'check_and_add_internal_links');

function check_and_add_internal_links() {
    if (is_single()) {
        global $post;
        $content = $post->post_content;

        // Check if the post has already been processed
        if (get_post_meta($post->ID, 'internal_link_added', true) == 'yes') {
            return;
        }

        // Check if there are any internal links
        if (has_internal_link($content)) {
            update_post_meta($post->ID, 'internal_link_added', 'yes');
            return;
        }

        // Add related posts if no internal links are found
        $new_content = add_related_posts($content, $post);
        if ($new_content) {
            // Update the post content
            wp_update_post(array(
                'ID' => $post->ID,
                'post_content' => $new_content,
            ));
            // Mark as processed
            update_post_meta($post->ID, 'internal_link_added', 'yes');
        }
    }
}

function has_internal_link($content) {
    $site_url = get_site_url();
    return strpos($content, $site_url) !== false;
}

function add_related_posts($content, $post) {
    $categories = wp_get_post_categories($post->ID);
    if (empty($categories)) {
        return $content;
    }

    $args = array(
        'category__in' => $categories,
        'post__not_in' => array($post->ID),
        'posts_per_page' => 5,
        'orderby' => 'rand',
    );

    $related_posts = get_posts($args);
    if (empty($related_posts)) {
        return $content;
    }

    $related_posts_html = '<h3>Related Posts</h3><ul>';
    foreach ($related_posts as $related_post) {
        $related_posts_html .= '<li><a href="' . get_permalink($related_post->ID) . '">' . get_the_title($related_post->ID) . '</a></li>';
    }
    $related_posts_html .= '</ul>';

    return $content . $related_posts_html;
}
